The Records of Legislation and the Executives Proposals
Arguments
- term
A numeric or NULL value. Data is available from the 8th term onwards. Default is set to 8.
- session_period
An integer, numeric, or NULL. Valid options for the session are: 1, 2, 3, 4, 5, 6, 7, and 8. Default is set to NULL.
review_session_info()provides available session periods based on the Minguo (Taiwan) calendar.- verbose
Default value is TRUE. Displays details of the retrieved data, including the number, URL, and computing time.
Value
A list containing:
titleRecords of questions answered by the executives
query_timeQuery time
retrieved_numberNumber of observations
retrieved_termRetrieved term
urlRetrieved JSON URL
variable_namesVariables of the tibble dataframe
manual_infoOfficial manual: https://data.ly.gov.tw/getds.action?id=20 or use
get_variable_info("get_bills_2")dataA tibble dataframe with variables such as:
termLegislative term number
sessionPeriodSession period
sessionTimesSession times
meetingTimesExtraordinary session times
billNoBill number
billNameBill title
billOrgProposing unit/legislator
billProposerPrimary proposer
billCosignatoryCo-signed proposal
billStatusBill status
pdfUrlPDF download link for related documents
docUrlDOC download link for related documents
selectTermFiltering criteria based on term
Details
The get_bills_2 function produces a list, which includes query_time,
retrieved_number, retrieved_term, url, variable_names, manual_info, and data.
For the user manual and more information about the dataframe, use get_variable_info("get_bills_2").
Note
For more details about the dataframe's variables, use get_variable_info("get_bills_2")
or visit the API manual at https://data.ly.gov.tw/getds.action?id=20.
Category: Provides bill-proposal records for legislators and the executive
(available from the 8th term, 1st session, onwards).
See also
get_variable_info("get_bills_2"),review_session_info()