The Records of Response to the Questions by the Executives
Source:R/parlquestions.R
get_executive_response.RdProvides access to the records of parliamentary questions through the Legislative Yuan's V1 API interface.
Arguments
- term
integer, numeric or NULL. The default is NULL. The data is only available from 8th term.
- session_period
integer, numeric or NULL. Available options for the session is: 1, 2, 3, 4, 5, 6, 7, and 8. The default is set to NULL.
review_session_info()generates each session period available option period in Minguo (Taiwan) calendar.- verbose
logical, indicates whether
get_executive_responseshould print out detailed output when retrieving the data. The default is set to TRUE
Value
list contains:
titlethe records of the questions answered by the executives
query_timethe queried time
retrieved_numberthe total number of observations
retrieved_termthe queried term
urlthe retrieved json url
variable_namesthe variables of the tibble dataframe
manual_infothe offical manual
dataa tibble dataframe, whose variables include:
sessionPeriodSession period
sessionTimesSession times
meetingTimesExtraordinary session times
eyNumberExecutive Yuan document reference number
lyNumberLegislative Yuan document reference number
subjectSubject
contentContent
docUrlSubject
itemFile download location
itemFile download location
selectTermTerm/session filtering criteria
Details
get_executive_response produces a list, which contains title,
query_time, retrieved_number, retrieved_term, url, variable_names,
manual_info and data. To retrieve the user manual and more information, please
use get_variable_info("get_executive_response").
#'@note To retrieve the user manual and more information about variable of the data
frame, please use get_variable_info("get_executive_response")
or visit the API manual at https://data.ly.gov.tw/getds.action?id=2.
Category: Provides records of the Executive Yuan's responses to legislators'
questions in the gazette (available from the 8th term, 1st session, onwards).
See also
get_variable_info("get_executive_response"), review_session_info()