Provides access to legislators' basic demographic and background information through the Legislative Yuan's V1 API interface.
Value
list contains:
query_timethe queried time
queried_termthe queried term
urlthe retrieved json url
variable_namesthe variables of the tibble dataframe
manual_infothe official manual from https://data.ly.gov.tw/getds.action?id=16, or use legisTaiwan::get_variable_info("get_legislators")
dataa tibble dataframe, whose variables include:
nameLegislator's name (Chinese)
enameLegislator's name (English)
sexGender
partyPolitical party affiliation
partyGroupParty group/caucus
committeeCommittee assignment
onboardDateOnboard date (Gregorian year)
degreeEducation background
experienceWork experience
picPathPhoto URL/path
leaveFlagLeave date (Gregorian year)
leaveReasonReason for leaving
Details
This function retrieves comprehensive data about legislators including their personal information, political background, and demographic details. The data is available starting from the 2nd legislative term.
get_legislators produces a list, which contains query_time,
queried_term, url, variable_names, manual_info and data.
Note
To retrieve the user manual and more information about variable of the data
frame, please use get_variable_info("get_legislators")
or visit the API manual at https://data.ly.gov.tw/getds.action?id=16.
Provides legislators' basic information; the earliest available data goes
back to the 2nd term.
See also
get_variable_info("get_legislators"), review_session_info()