Provides access to legislators' spoken meeting records through the Legislative Yuan's V1 API interface.
Arguments
- start_date
numeric Must be formatted in Minguo (Taiwan) calendar, e.g. 1090101.
- end_date
numeric Must be formatted in Minguo (Taiwan) calendar, e.g. 1090102.
- meeting_unit
NULL The default is NULL, which includes all meeting types between the starting date and the ending date.
- verbose
logical, indicates whether
get_meetingsshould print out detailed output when retrieving the data.
Value
list, which contains:
titlethe spoken meeting records
query_timethe query time
retrieved_numberthe number of the observation
meeting_unitthe meeting unit
start_date_adthe start date in POSIXct
end_date_adthe end date in POSIXct
start_datethe start date in ROC Taiwan calendar
urlthe retrieved json url
variable_namesthe variables of the tibble dataframe
manual_infothe offical manual, https://www.ly.gov.tw/Pages/List.aspx?nodeid=154; or use get_variable_info("get_meetings")
dataa tibble dataframe, whose variables include:
meeting_statusMeeting status
meeting_nameMeeting name
meeting_contentMeeting subject
speechersList of speaking legislators
meeting_unitOrganizing unit
date_adGregorian year
Details
get_meetings produces a list, which contains title, query_time,
retrieved_number, meeting_unit, start_date_ad, end_date_ad, start_date,
end_date, url, variable_names, manual_info and data.
Note
To retrieve the user manual and more information about variable of the data
frame, please use get_variable_info("get_meetings") or visit
the API manual at https://www.ly.gov.tw/Pages/List.aspx?nodeid=154.
The data appears inconsistent and needs verification; the earliest available
date for spoken meeting records is unclear and needs checking.
See also
get_variable_info("get_meetings")
Regarding Minguo calendar, please see https://en.wikipedia.org/wiki/Republic_of_China_calendar.
Examples
if (FALSE) { # \dontrun{
## query meeting records by a period of the dates in Minguo (Taiwan) calendar
get_meetings(start_date = "1050120", end_date = "1050210")
## query meeting records by a period of the dates in Minguo (Taiwan) calendar format
## and a meeting; meeting_unit is a Chinese committee name, e.g. "Interior Committee"
get_meetings(start_date = 1060120, end_date = 1070310, meeting_unit = "Interior Committee")
} # }