The Records of National Public Debates
Arguments
- term
numeric or NULL. The default is set to 10. Legislative term number (e.g., 10). Data is officially available from the 8th term onwards, but testing shows data starts from the 10th term.
- session_period
numeric or NULL. Session period number (1-8). Default is NULL. Use
review_session_info()to see available session periods in ROC calendar.- verbose
logical. Whether to display download progress and detailed information. Default is TRUE.
Value
A list containing:
titlepublic debates records
query_timequery timestamp
retrieved_numbernumber of records retrieved
retrieved_termqueried legislative term
urlretrieved API URL
variable_namesvariables in the tibble dataframe
manual_infoofficial manual URL or use get_variable_info("get_public_debates")
dataa tibble dataframe containing:
termTerm number
sessionPeriodSession period
sessionTimesSession times
meetingTimesExtraordinary session times
dateTimeDescDate/time description
meetingRoomMeeting room
chairmanChairperson
legislatorNameLegislator's name
speakTypeSpeech type (paper: written statement, speak: spoken)
contentContent
selectTermTerm/session filtering criteria
Details
The function retrieves records from the National Public Debates, including both spoken and written opinions. While officially available from the 8th legislative term, testing indicates data is only available from the 10th term onwards.
Note
For more details about the data variables and API information,
use get_variable_info("get_public_debates") or visit the API manual at
https://data.ly.gov.tw/getds.action?id=7.
Category: Provides National Public Debate records from the gazette,
including written opinions. Officially available from the 8th term, 1st
session, onwards, but testing shows data only starts from the 10th term.
See also
get_variable_info("get_public_debates")For ROC calendar information: https://en.wikipedia.org/wiki/Republic_of_China_calendar